﻿(function () {

    "use strict";

    angular.module("enrOfficeSelectionModule", [])
           .directive("enrOfficeSelection", [function () {

               // Default selection to first item in list.
               function link(scope) {
                   var deregisterWatch = scope.$watch("listData", function (newElectionOfficesList) {
                       if (newElectionOfficesList) {
                           for (var i = 0; i < newElectionOfficesList.List.length; i++) {
                               var curOfficeHeading = newElectionOfficesList.List[i];

                               if (curOfficeHeading.Items && curOfficeHeading.Items.Item && curOfficeHeading.Items.Item.length && curOfficeHeading.Items.Item.length > 0) {
                                   scope.handleOfficeClicked(curOfficeHeading.Items.Item[0]);
                                   break;
                               }
                           }
                           
                           deregisterWatch();
                       }
                   });
               }

               return {
                   link:link,
                   templateUrl: "Scripts/EnrAngular/Directives/enrOfficeSelection.html",
                   scope: { listData: "=", defaultMap: "=" },
                   restrict: "E",
                   controller: "enrOfficeSelectionController"
               };
           }])
           .controller("enrOfficeSelectionController", ["$scope", "$rootScope", "$timeout", "jsonDataFetcher", "enrModeManager", "detailsData", function ($scope, $rootScope, $timeout, jsonDataFetcher, enrModeManager, detailsData) {
               var mapJsonFileName;
               var officeSummaryJsonFileName;

               var fetchMapData = function() {
                   jsonDataFetcher.fetchMultipleJson([mapJsonFileName, officeSummaryJsonFileName], [false, true], [true, false], function (jsonResults) {
                       var mapJson = jsonResults[0];
                       var officeSummaryJson = jsonResults[1];

                       // Update map to match selection
                       $scope.$parent.MapGeoData = mapJson;
                       $scope.$parent.MapElectionData = officeSummaryJson;

                       detailsData.setData(officeSummaryJson);
                   });
               };

               $scope.handleOfficeClicked = function (clickedListItem) {
                   // Deselect any selected items
                   angular.forEach($scope.listData.List, function (listItem) {
                       if (listItem.Items && listItem.Items.Item) {
                           angular.forEach(listItem.Items.Item, function (subItem) {
                               subItem.IsSelected = false;
                           });
                       }
                   });

                   clickedListItem.IsSelected = true;

                   // Fetch Map and Office Summary Data
                   mapJsonFileName = clickedListItem.MAPCODE;
                   if (mapJsonFileName === undefined)
                       mapJsonFileName = $scope.defaultMap;
                   officeSummaryJsonFileName = "OffCatC_" + clickedListItem.OFFICECATEGORYID;

                   // This could take some time. Show busy working.
                   $rootScope.$broadcast("PUSH_BUSY_WORKING");
                   // Delay execution of syncronous logic to give the busy working effect time to appear before causing ui-locking.
                   $timeout(fetchMapData, 500);
               };

               $scope.$on(enrModeManager.modeChangeEventName, function (event, newMode) {
                   if (newMode === enrModeManager.modeEnum.offices)
                       fetchMapData();
               });
           }]);

}());
